@@ -503,7 +503,7 @@ class Trainer:
         for k, v in inputs.items():
             inputs[k] = v.to(self.args.device)
 
-        outputs = model(**inputs, labels=inputs.labels)
+        outputs = model(**inputs)
         loss = outputs[0]  # model outputs are always tuple in transformers (see doc)
 
         if self.args.n_gpu > 1:
@@ -681,15 +681,15 @@ class Trainer:
 
         for inputs in tqdm(dataloader, desc=description):
             has_labels = any(inputs.get(k) is not None for k in ["labels", "lm_labels", "masked_lm_labels"])
-            newInputs = {}
+
             for k, v in inputs.items():
                 if k != 'guid':
-                    newInputs[k] = v.to(self.args.device)
+                    inputs[k] = v.to(self.args.device)
                 else:
                     guids.append(v)
 
             with torch.no_grad():
-                outputs = model(**newInputs)
+                outputs = model(**inputs)
                 if has_labels:
                     step_eval_loss, logits = outputs[:2]
                     eval_losses += [step_eval_loss.mean().item()]
@@ -706,6 +706,10 @@ class Trainer:
                         label_ids = inputs["labels"].detach().cpu().numpy()
                     else:
                         label_ids = np.append(label_ids, inputs["labels"].detach().cpu().numpy(), axis=0)
+            logger.info(inputs)
+            logger.info(preds)
+            logger.info(label_ids)
+            break
 
         if is_tpu_available() and preds is not None and label_ids is not None:
             # tpu-comment: Get all predictions and labels from all worker shards of eval dataset
